.. :changelog:

Release History
---------------

1.0.0-alpha (2018-06-13)
~~~~~~~~~~~~~~~~~~~~~~~~
- Update to the `new Fixer endpoint <https://data.fixer.io/api/>`_.
- Add Fixer API Access Key support.
- Drop Changing base currency support. This option is not supported by Free Plan.
- Drop SSL Encryption support. This option is not supported by Free Plan.

0.1.1 (2016-06-16)
~~~~~~~~~~~~~~~~~~

- Initial version.
